import QtQuick 1.1
import "../imports/XAComponents"
import "../Map"

Item {
    id: maincomponent

    property string itemComment: ""
    property string itemPlaceholder: ""
    property alias text: commentField.text

    property bool isEditable: true

    property bool isEditing: false
    property bool isModified: false
    property bool isSelected: false

    signal updated(string newComment);
    signal itemClicked();

    property color tabPanelMarkerColor: "#d9d9d9"
    property Gradient tabPanelBackgroundGradient: Gradient {
        GradientStop { position: 0.0; color: "white" }
        GradientStop { position: 0.5; color: "#dddddd" }
        GradientStop { position: 1.0; color: "white" }
    }

    function activateFocus() {
        commentField.focus = true;
        commentField.forceActiveFocus();
    }

    onItemCommentChanged: {
        commentField.text = itemComment
//        detailsPanel.selectTab(itemPriority)
//        triggered(itemPriority)
    }

    Rectangle {
        id: detailsPanel
        anchors.fill: parent

        color: "transparent"

        Image {
            id: backgroundImageTop
            anchors.top: parent.top
            anchors.horizontalCenter: parent.horizontalCenter

            source: "qrc:/icons/NoteBackgroundTopSlice001.png"

            Text {
                id: backgroundTitlePlaceholder
                anchors.top: parent.top
                anchors.topMargin: 3
                anchors.horizontalCenter: parent.horizontalCenter

                text: maincomponent.itemPlaceholder

                font.family: "Helvetica Neue"
                font.pixelSize: 12
                font.bold: false

                color: "#aaaaaa"
            }

            MouseArea {
                anchors.fill: parent

                onPressed: {
                    itemClicked();
                    commentField.focus = true
                }
            }
        }

        Image {
            id: backgroundImageMiddle
            anchors.top: backgroundImageTop.bottom
            anchors.bottom: backgroundImageBottom.top
            anchors.horizontalCenter: parent.horizontalCenter

            fillMode: Image.TileVertically

            source: "qrc:/icons/NoteBackgroundMiddleSlice001.png"

            Flickable {
                id: flickArea
                anchors.fill: parent
                anchors.leftMargin: 6
                anchors.rightMargin: 6
                contentWidth: commentField.width; contentHeight: commentField.height
                flickableDirection: Flickable.VerticalFlick
                clip: true

                TextEdit {
                    id: commentField
                    width: flickArea.width-18

                    font.pixelSize: 12
                    //                cursorVisible: false
                    selectByMouse: true
                    selectionColor: "lightblue"
                    smooth: true
                    wrapMode: TextEdit.Wrap

                    //focus: maincomponent.focus
                    enabled: maincomponent.isEditable
                    activeFocusOnPress: true

                    onTextChanged: {
                        updated(text)
                        maincomponent.isModified = true

                        //console.debug("commentField onTextChanged")
                        scroller1.updateSizing();
                    }

                    onFocusChanged: {
                        //console.debug("commentField onFocusChanged")
                        //console.debug(focus)
                    }

                    onCursorRectangleChanged: {
                        //console.debug("cursor position: (" + cursorRectangle.y + ")")
                        //console.debug("flickable position: (" + flickArea.contentY + " - " + flickArea.contentHeight + ")")
                        if (cursorRectangle.y + cursorRectangle.height > flickArea.contentY+flickArea.height) {
                            //console.debug("cursor outside > bottom")
                            flickArea.contentY = (cursorRectangle.y + cursorRectangle.height) - flickArea.height

                        } else if (cursorRectangle.y < flickArea.contentY) {
                            //console.debug("cursor outside > top")
                            flickArea.contentY = cursorRectangle.y
                        }
                    }

                    MouseArea {
                        anchors.fill: parent
                        visible: !commentField.focus

                        onPressed: {
                            //console.debug("Date Picker requested in Line Input")
                            itemClicked();

                            commentField.focus = true
                            commentField.forceActiveFocus()
                        }
                    }
                }
            }

            MouseArea {
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: parent.top
                anchors.topMargin: (flickArea.top + commentField.height < flickArea.bottom) ? flickArea.top + commentField.height : commentField.height
                anchors.bottom: parent.bottom

                visible: !commentField.focus

                onPressed: {
                    itemClicked();
                    commentField.focus = true
                    commentField.forceActiveFocus()
                }
            }
        }

        XATextScrollBar {
            id: scroller1
            scrollArea: flickArea;
            width: 12

            visible: (commentField.paintedHeight > flickArea.height)

            anchors { right: backgroundImageMiddle.right; rightMargin: 6; top: backgroundImageMiddle.top; bottom: backgroundImageMiddle.bottom; }
        }

        Image {
            id: backgroundImageBottom
            anchors.bottom: parent.bottom
            anchors.horizontalCenter: parent.horizontalCenter

            source: "qrc:/icons/NoteBackgroundBottomSlice001.png"

            MouseArea {
                anchors.fill: parent

                onPressed: {
                    itemClicked();
                    commentField.focus = true
                }
            }
        }

    }
}
