import Qt 4.7

Item {
    id: xaqmlButton

    property alias operation: buttonText.text
    property alias font: buttonText.font
    property alias textColor: buttonText.color
    property bool enabled: true
    property bool framed: false
    property bool selected: false
    property bool runOp: true
    property string opcode: ""
    property bool buttonMode: true
    property int spacerBottomHeight: 1
    property bool macStyle: false

    signal clicked

    function loadSettings() {
        //console.debug("XAQMLButton loading... ")
        //if (macStyle) console.debug("MAC")
        //else console.debug("WIN")

        if (xaqmlButton.buttonMode) {
            // display as button with markup
            if (xaqmlButton.enabled) {
                if (xaqmlButton.selected) shade.gradient = selectedEnabledGradient
                else shade.gradient = enabledGradient
            } else {
                if (xaqmlButton.selected) shade.gradient = selectedDisabledGradient
                else shade.gradient = disabledGradient
            }

            buttonText.color = "white"
            buttonShadow.color = "black"

            outerFrame.border.width = 1
            outerFrame.border.color = "black"

            if (xaqmlButton.selected) innerFrame.border.width = 0
            else innerFrame.border.width = 1
            innerFrame.border.color = "#666666"

            var radius = 0
            if (xaqmlButton.macStyle) radius = 6;

            //console.debug("setting radius: " + radius)
            outerFrame.radius = radius
            innerFrame.radius = radius
            shade.radius = radius

        } else {
            // display as header, no markup
            shade.color = "transparent";
            shade.border.width = 0;

            buttonText.color = "white"
            buttonShadow.color = "transparent"

            outerFrame.border.width = 0
            innerFrame.border.width = 0
        }
    }

    onFramedChanged: loadSettings()
    onEnabledChanged: loadSettings()
    onSelectedChanged: loadSettings()
    onMacStyleChanged: loadSettings()

    Gradient {
        id: noGradient
    }

    Gradient {
        id: enabledGradient
        GradientStop { position: 0.0; color: "#333333" }
        GradientStop { position: 0.5; color: "#3F3B3C" }
        GradientStop { position: 1.0; color: "#333333" }
    }
    Gradient {
        id: disabledGradient
        GradientStop { position: 0.0; color: "#333333" }
        GradientStop { position: 0.5; color: "#333333" }
        GradientStop { position: 1.0; color: "#333333" }
    }

    Gradient {
        id: selectedEnabledGradient
        GradientStop { position: 0.0; color: "#6396f8" }
        GradientStop { position: 0.5; color: "#2356b8" }
        GradientStop { position: 1.0; color: "#2356b8" }
    }
    Gradient {
        id: selectedDisabledGradient
        GradientStop { position: 0.0; color: "white" }
        GradientStop { position: 0.8; color: "#717171" }
        GradientStop { position: 1.0; color: "#3e3e3e" }
    }

//    border { left: 10; top: 10; right: 10; bottom: 10 }

    Rectangle {
        id: shade
        anchors.fill: xaqmlButton;  color: "black"
        gradient: enabledGradient
        smooth: true
        clip: true
    }

    Rectangle {
        id: outerFrame
        anchors.fill: xaqmlButton;
        border.width: 1
        border.color: "black"
        color: "transparent"
        smooth: true

        clip: true
    }

    Rectangle {
        id: innerFrame
        anchors.fill: xaqmlButton;
        anchors.leftMargin:1; anchors.rightMargin: 1; anchors.topMargin: 1; anchors.bottomMargin: 1;
        border.width: 1
        border.color: "#666666"
        color: "transparent"
        smooth: true

        clip: true
    }


    Text {
        id: buttonShadow
        anchors.centerIn: parent; anchors.verticalCenterOffset: +3; anchors.horizontalCenterOffset: +1
        font.family: buttonText.font.family
        font.pixelSize: buttonText.font.pixelSize
        smooth: true

        text: buttonText.text
    }

    Text {
        id: buttonText
        anchors.centerIn: parent; anchors.verticalCenterOffset: +2 - (macStyle ? 0 : 2); anchors.horizontalCenterOffset: +1
        font.family: "Arial"
        font.pixelSize: (xaqmlButton.width > xaqmlButton.height ? Math.abs(xaqmlButton.height * .6) : Math.abs(xaqmlButton.width * .6)) - (macStyle ? 0 : 2)
        smooth:true

    }

    MouseArea {
        id: mouseArea
        anchors.fill: parent
        onClicked: {
            if (xaqmlButton.enabled) {
                selected = true;
                console.debug("OPERATION: " + operation);

                if (xaqmlButton.runOp) doOp(opcode, operation);

                xaqmlButton.clicked();
            }
        }

        onReleased: selected = false;
    }

    states: [
        State {
            name: "pressed"; when: mouseArea.pressed === true && xaqmlButton.enabled
            PropertyChanges { target: shade; opacity: .8 }
        }
        ,
        State {
            name: "released"; when: mouseArea.pressed === false
            PropertyChanges { target: shade; opacity: 0 }
        }
    ]

    Component.onCompleted: loadSettings()
}
